@@ -16,7 +16,6 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 from rat import Rat
-import unittest
 import mfutils
 
 class EventBase(object):
@@ -274,7 +273,6 @@ class MidiEventStream(object):
         f.close()
 
 
-
 class Track:
     """
     A pitch is represented by an integer value 0-127.
@@ -385,57 +383,3 @@ class PercussionTrack(Track):
     def __init__(self):
         Track.__init__(self)
 
-def test_track():
-    t1 = Track()
-    t1.start_note(70, 127)
-    t1.notelen_time(Rat(1, 4))
-    t1.stop_note(70, 127)
-    t1.set_patch(8)
-    t1.start_note(71, 126)
-    t1.notelen_time(Rat(1, 16))
-    t1.stop_note(71, 126)
-    t2 = Track()
-    t2.start_note(80, 127)
-    t2.notelen_time(Rat(1, 2))
-    t2.stop_note(80, 127)
-    #t1.txtdump()
-    print "-" * 60
-    t1.txtdump()
-    print "---"
-    t2.txtdump()
-    m = MidiEventStream(t1, t2)
-    for e in m:
-        print e
-
-class TestClass(unittest.TestCase):
-    def test_simple1(self):
-        t = Track()
-        t.note(4, 90, 127)
-        self.assertEquals(list(MidiEventStream(t)),
-          [('program-change', 0, 0),
-           ('note-on', 0, 90, 127),
-           ('notelen-time', Rat(1, 4)),
-           ('note-off', 0, 90, 127)])
-    def test_1voice_setpatch(self):
-        t = Track()
-        t.note(4, 90, 127)
-        t.set_patch(3)
-        t.note(4, 91, 127)
-        for e in MidiEventStream(t): print "e:", e
-        self.assertEquals(list(MidiEventStream(t)),
-          [('program-change', 0, 0),
-           ('note-on', 0, 90, 127),
-           ('notelen-time', Rat(1, 4)),
-           ('note-off', 0, 90, 127),
-           ('program-change', 0, 3),
-           ('note-on', 0, 91, 127),
-           ('notelen-time', Rat(1, 4)),
-           ('note-off', 0, 91, 127),
-           ])
-
-
-if __name__ == '__main__':
-    import testsetup
-    import unittest
-    unittest.main()
-    #test_track()
