@@ -18,12 +18,9 @@
 import configureoutput
 import errno, sys
 import locale
-import shutil
 import soundcard, mpd
 import lessonfile
 import dataparser
-import statistics
-import abstract
 import os
 import cfg, utils
 import webbrowser
@@ -239,7 +236,7 @@ It is also possible that the OS sound setup is incorrect.
         self.m_ui.enter_test_mode()
     def handle_href(self, href, display_docfile_set_adj=1):
         # All generatet docbook documents are in utf-8
-        urlobj = utils.Url(href.decode("utf-8"))
+        urlobj = utils.Url(href)
         if not urlobj.protocol:
             if urlobj.filename.endswith(".midi"):
                 if os.path.exists(os.path.join(self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, urlobj.filename)):
@@ -377,6 +374,8 @@ It is also possible that the OS sound setup is incorrect.
                     soundcard.synth.end_export()
                 elif module in ('melodicinterval', 'harmonicinterval'):
                     t = self.m_teachers[module]
+                    t.set_lessonfile(self.lessonfile_manager.get(lesson_id, 'filename'))
+                    t.start_practise()
                     t.new_question("c", "c''")
                     t.q_status = const.QSTATUS_SOLVED
                     try:
@@ -422,7 +421,7 @@ It is also possible that the OS sound setup is incorrect.
                             # every single file.
                             output_format = 'midi'
                             self.m_ui.display_error_message2("External program must have failed", "The file in %(from)s format was not generated from the %(to)s file as expected. Please check your setup." % {'to':to_format.upper(), 'from': from_format.upper()})
-                    except (TypeError, KeyError), e:
+                    except (TypeError, KeyError):
                         self.m_ui.display_error_message2("%(from)s to %(to)s config error", "There was a format string error. Will not generate WAV files. Please check the app/midi_to_wav_cmd config variable." % {'from': from_format, 'to': to_format})
                         output_format = 'midi'
                     return True
