@@ -15,10 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-if __name__ == '__main__':
-    import testsetup
 
-import unittest
 import gtk
 import gobject
 import pprint
@@ -76,7 +73,7 @@ class LearningTree:
         self.m_visibility = 0
         self.m_learning_tree_version = 0
         g = {'_': lambda s: s}
-        v = eval(file(filename, 'r').read(), g)
+        v = eval(open(filename, 'r').read(), g)
         if len(v) == 2:
             self.m_menus, self.m_deps = v
         elif len(v) == 3:
@@ -121,7 +118,7 @@ class LearningTree:
         self.calculate_visibilities()
         self.m_modified = False
     def save(self, filename):
-        ofile = file(filename, 'w')
+        ofile = open(filename, 'w')
         print >> ofile, "[ # toplevel list"
         print >> ofile, "  %s, # learning tree file format version" % self.m_learning_tree_version
         print >> ofile, "  [ # start of list of menus"
@@ -228,10 +225,7 @@ class LearningTree:
         p = path[:-1]
         i = path[-1]
         move_id = self.get(path)
-        try:
-            next_id = self.get(Path(path).next())
-        except IndexError:
-            return
+        next_id = self.get(Path(path).next())
         if move_id not in list(self.iter_subdeps(next_id)):
             try:
                 self.get(p).children[i], self.get(p).children[i + 1] = \
@@ -822,7 +816,7 @@ class Window(gtk.Window):
                     try:
                         if not os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees')):
                             os.makedirs(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees'))
-                        f = file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename), 'w')
+                        f = open(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename), 'w')
                         f.write("""
 [ # toplevel list
   2, # learning tree file format version
@@ -1143,7 +1137,6 @@ class Window(gtk.Window):
             del_elem = self.m_tree.get(path)
             if isinstance(del_elem, Menu):
                 self.delete_menu(path)
-                self.treeview_cursor_changed()
                 return
             del_id = del_elem
             do_del = True
@@ -1207,67 +1200,3 @@ class Window(gtk.Window):
         #if self.g_topics_liststore.get_iter_first():
         #    self.g_topics.set_cursor("0", None)
 
-class TestLearningTree(unittest.TestCase):
-    def testCreate(self):
-        tree = LearningTree(None)
-        tree.new_menu("Menu 1")
-    def create_menu(self):
-        tree = LearningTree(None)
-        tree.new_menu("Menu 1")
-        tree.new_topic(0, "Submenu 0")
-        tree.new_topic(0, "Submenu 1")
-        tree.new_menu("Menu 2")
-        tree.new_topic(1, "Submenu 1-0")
-        tree.new_topic(1, "Submenu 1-1")
-        return tree
-    def test_move_elem_up(self):
-        tree = self.create_menu()
-        self.assertEqual(tree.get((0, 0))['name'], 'Submenu 0')
-        self.assert_(tree.move_elem_up((0, 1)))
-        self.assertEqual(tree.get((0, 0))['name'], 'Submenu 1')
-        self.assertEqual(tree.get((0, 1))['name'], 'Submenu 0')
-        self.assertEqual(tree.move_elem_up((3, 3)), False, 
-            'Should fail. Invalid path given to function.')
-        self.assertEqual(tree.move_elem_up((1, 0)), False,
-            'Should fail. Trying to move the first element up.')
-        self.assertEqual(tree.move_elem_up((1,)), False,
-            'Should fail becuase move_elem_up cannot move toplevel menus')
-    def test_move_elem_to_prev_menu(self):
-        tree = self.create_menu()
-        self.assertEqual(tree.move_elem_to_prev_menu((1, 0)), (0, 2))
-        self.assertEqual(tree.get((0, 2))['name'], 'Submenu 1-0')
-    def test_iterate_all_lessons(self):
-        tree = LearningTree(None)
-        tree.new_menu("Menu 1")
-        tree.new_topic(0, "Submenu 0")
-        tree.add_lesson((0, 0), "id1")
-        tree.add_lesson((0, 0), "id2")
-        tree.add_lesson((0, 0), "id3")
-        v = list(tree.iterate_all_lessons())
-        self.assertEqual(v, ['id1', 'id2', 'id3'])
-    def test_iterate_all_lessons2(self):
-        tree = LearningTree(None)
-        tree.new_menu("Menu 1")
-        tree.new_topic(0, "Submenu 0")
-        tree.add_lesson((0, 0), "id1")
-        tree.add_lesson((0, 0), "id2")
-        tree.add_lesson((0, 0), "id3")
-        tree.new_topic(0, "Submenu 1")
-        tree.add_lesson((0, 1), "id11")
-        tree.add_lesson((0, 1), "id12")
-        tree.add_lesson((0, 1), "id13")
-        v = list(tree.iterate_all_lessons2())
-        self.assertEqual(v, [('id1', (0, 0, 0)), ('id2', (0, 0, 1)), ('id3', (0, 0, 2)), ('id11', (0, 1, 0)), ('id12', (0, 1, 1)), ('id13', (0, 1, 2))])
-
-
-
-if __name__ == '__main__':
-    unittest.main()
-    #import lessonfile
-    #manager = lessonfile.LessonFileManager()
-    #tree = LearningTree(manager)
-    #tree.load("learningtree.txt")
-    #tree.save("ut.txt")
-    #for n in tree.iterate_topics_for_id("solfege.org-all-harmonic-intervals"):
-    #    print n, type(n)
-
