@@ -19,11 +19,24 @@
 
 copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>, and others."
 
+import time
+t1 = time.clock()
 import sys
 import os
 import time
 import urllib
 
+# The sets module was added in python 2.3. So we will use that module
+# if we are running python 2.3, and the builtin set if we are using
+# python 2.4
+# FIXME: remove this code when we require python 2.4
+try:
+    set()
+except NameError:
+    import __builtin__
+    import sets
+    __builtin__.set = sets.Set
+
 import runtime
 
 import configureoutput
@@ -173,6 +186,7 @@ import harmonicinterval
 import melodicinterval
 import singinterval
 import nameinterval
+import example
 
 import idbyname
 import dictation
@@ -788,6 +802,6 @@ def start_app(prefix, datadir):
         else:
             sys.__excepthook__(t, msg, traceback)
     sys.excepthook = ef
-    import gtk
+    print time.clock() - t1
     gtk.main()
 
