@@ -24,6 +24,7 @@ from gethomedir import get_home_dir
 import gu
 import configureoutput
 from dataparser import Dataparser, DataparserException
+import lessonfile
 
 
 # The definition of a training set will be stored in a file in the
@@ -32,6 +33,11 @@ from dataparser import Dataparser, DataparserException
 class TrainingSetDialog(gtk.Window):
     instance_counter = 0
     fileformat_version = 1
+    STORE_LESSON_ID = 0
+    STORE_TITLE = 1
+    STORE_COUNT = 2
+    STORE_REPEAT = 3
+    STORE_DELAY = 4
     def __init__(self, app):
         gtk.Window.__init__(self)
         TrainingSetDialog.instance_counter += 1
@@ -60,18 +66,74 @@ class TrainingSetDialog(gtk.Window):
         hbox.pack_start(gtk.Label(_("Preferred output format:")), False)
         for s in ('midi', 'wav', 'mp3', 'ogg'):
             hbox.pack_start(self.g_output[s], False)
-        # The box containing one widget per lesson file that is used in the set
-        sc = gtk.ScrolledWindow()
-        self.g_vbox.pack_start(sc)
-        self.g_ebox = gtk.VBox()
-        self.g_ebox.set_border_width(6)
-        sc.add_with_viewport(self.g_ebox)
+        ####
+        self.g_liststore = gtk.ListStore(
+            gobject.TYPE_STRING, # lesson_id
+            gobject.TYPE_STRING, # visible exercise name
+            gobject.TYPE_INT, # count
+            gobject.TYPE_INT, # repeat
+            gobject.TYPE_INT) # delay
+        self.g_treeview = gtk.TreeView(self.g_liststore)
+        self.g_treeview.set_size_request(400, 100)
+        self.g_treeview.connect('cursor-changed',
+            self.on_treeview_cursor_changed)
+
+        renderer = gtk.CellRendererText()
+        column = gtk.TreeViewColumn(_("Title"), renderer, text=self.STORE_TITLE)
+        self.g_treeview.append_column(column)
+        renderer = gtk.CellRendererText()
+        renderer.set_property('editable', True)
+        renderer.connect('edited', self.on_count_edited)
+        column = gtk.TreeViewColumn(_("Count"), renderer,
+                                    text=self.STORE_COUNT)
+        self.g_treeview.append_column(column)
+        renderer = gtk.CellRendererText()
+        renderer.set_property('editable', True)
+        renderer.connect('edited', self.on_repeat_edited)
+        column = gtk.TreeViewColumn(_("Repeat"), renderer,
+                                    text=self.STORE_REPEAT)
+        self.g_treeview.append_column(column)
+        renderer = gtk.CellRendererText()
+        renderer.set_property('editable', True)
+        renderer.connect('edited', self.on_delay_edited)
+        column = gtk.TreeViewColumn(_("Delay"), renderer, text=self.STORE_DELAY)
+        self.g_treeview.append_column(column)
+        self.g_vbox.pack_start(self.g_treeview)
         self.init_empty_file()
-        self.add_newbutton()
-    def add_newbutton(self):
-        self.g_add_lesson = gtk.Button(_("Add lesson file"))
-        self.g_add_lesson.connect('clicked', self.on_add_lesson_clicked)
-        self.g_ebox.pack_start(self.g_add_lesson, False)
+        self.show_all()
+    def on_treeview_cursor_changed(self, treeview):
+        self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(True)
+    def on_count_edited(self, renderer, path, text):
+        self._edit_col(2, path, text)
+    def on_repeat_edited(self, renderer, path, text):
+        self._edit_col(3, path, text)
+    def on_delay_edited(self, renderer, path, text):
+        self._edit_col(4, path, text)
+    def _edit_col(self, col_num, path, text):
+        """
+        This method does the real work when on_XXXX_edited is called.
+        """
+        try:
+            i = int(text)
+        except ValueError:
+            i = None
+        if i is not None:
+            iter = self.g_liststore.get_iter_from_string(path)
+            self.g_liststore.set_value(iter, col_num, i)
+    def on_remove_lesson_clicked(self, *w):
+        path, column = self.g_treeview.get_cursor()
+        assert path
+        iter = self.g_liststore.get_iter(path)
+        if iter:
+            if self.g_liststore.remove(iter):
+                self.g_treeview.set_cursor(self.g_liststore.get_path(iter))
+            elif path[0] > 0:
+                self.g_treeview.set_cursor((path[0]-1,))
+            else:
+                self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(False)
+        else:
+            print "NOt delete because not iter"
+        print "ITER:", iter
     def on_add_lesson_clicked(self, button):
         menu = self.create_learning_tree_menu()
         menu.popup(None, None, None, 1, 0)
@@ -85,49 +147,23 @@ class TrainingSetDialog(gtk.Window):
         if module not in ('harmonicinterval', 'melodicinterval', 'idbyname'):
             print "Only harmonicinterval, melodicinterval and idbyname module exercises are working now. Ignoring..."
             return
-        self.m_filedata.append({'lesson_id': lesson_id, 'count': 3, 'repeat': 3, 'delay': 4})
+        if module == 'idbyname':
+            fn = self.m_app.lessonfile_manager.get(lesson_id, 'filename')
+            p = lessonfile.LessonfileCommon(fn)
+            p.parse_file(fn)
+            if not [q for q in p.m_questions if q['music'].is_mpd_parsable()]:
+                gu.dialog_ok(_("This lesson file cannot be exported because some of the music in the file are not parsable by the mpd module."))
+                return
         self.m_changed = True
-        self.append_lesson(self.get_lessonfile_title(lesson_id))
-        self.move_newbutton_last()
+        self.g_liststore.append((
+            lesson_id, self.get_lessonfile_title(lesson_id),
+            3, 3, 4))
     def get_lessonfile_title(self, lesson_id):
         """
         Return a string we use the name the lesson file in the GUI.
         """
         return self.m_app.lessonfile_manager.get(lesson_id, 'title') \
             + " (%s)" % self.m_app.lessonfile_manager.get(lesson_id, 'filename')
-    def append_lesson(self, heading):
-        """
-        Create and append the gui for one exercise to g_ebox, and
-        append refs to the widgets to self.m_filedata.
-        """
-        def label_spin(txt):
-            hbox = gtk.HBox()
-            hbox.set_spacing(6)
-            l = gtk.Label(txt)
-            hbox.pack_start(l, False)
-            spin = gtk.SpinButton(gtk.Adjustment(1, 1, 100, 1, 10, 10))
-            hbox.pack_start(spin, False)
-            return hbox, spin
-        vbox, content = gu.hig_category_vbox(heading)
-        self.g_ebox.pack_start(vbox, False)
-        #
-        box, spin = label_spin(_("Number of questions to generate:"))
-        self.m_filedata[-1]['count'] = spin
-        content.pack_start(box, False)
-        #
-        box, spin = label_spin(_("Number of times to repeat each questions:"))
-        self.m_filedata[-1]['repeat'] = spin
-        content.pack_start(box, False)
-        #
-        box, spin = label_spin(_("Semitones delay after each question:"))
-        self.m_filedata[-1]['delay'] = spin
-        content.pack_start(box, False)
-        content.show_all()
-    def move_newbutton_last(self):
-        """
-        Move the button used to add a new lesson to the end of the list.
-        """
-        self.g_ebox.reorder_child(self.g_add_lesson, len(self.g_ebox.get_children()))
     def create_learning_tree_menu(self):
         """
         Create and return a gtk.Menu object that has submenus that
@@ -142,7 +178,30 @@ class TrainingSetDialog(gtk.Window):
             if isinstance(menudata, list):
                 menu = gtk.Menu()
                 for lesson_id in menudata:
-                    i = gtk.MenuItem(self.m_app.lessonfile_manager.get(lesson_id, 'title'))
+                    if self.m_app.lessonfile_manager.get(lesson_id, 'module') not in ('melodicinterval', 'harmonicinterval', 'idbyname'):
+                        continue
+                    # We don't want to add these lesson files because we know
+                    # that they cannot be exported. It would be better
+                    # to catch these with a more generit algorithm, but
+                    # then we would have to parse all the files, and that
+                    # would be too slow.
+                    if lesson_id in (
+                            # melodic-interval-self-config
+                            "f62929dc-7122-4173-aad1-4d4eef8779af",
+                            # harmonic-interval-self-config
+                            "466409e7-9086-4623-aff0-7c27f7dfd13b",
+                            # the csound-fifth-* files:
+                            "b465c807-d7bf-4e3a-a6da-54c78d5b59a1",
+                            "aa5c3b18-664b-4e3d-b42d-2f06582f4135",
+                            "5098fb96-c362-45b9-bbb3-703db149a079",
+                            "3b1f57e8-2983-4a74-96da-468aa5414e5e",
+                            "a06b5531-7422-4ea3-8711-ec57e2a4ce22",
+                            "e67c5bd2-a275-4d9a-96a8-52e43a1e8987",
+                            "1cadef8c-859e-4482-a6c4-31bd715b4787",
+                            ):
+                        continue
+                    i = gtk.MenuItem(
+                        self.m_app.lessonfile_manager.get(lesson_id, 'title'))
                     i.set_data('lesson_id', lesson_id)
                     i.set_data('menus', parent_name)
                     i.connect('activate', self.on_select_exercise)
@@ -161,13 +220,24 @@ class TrainingSetDialog(gtk.Window):
             menu.append(create_submenu(m, [_(m['name'])]))
 
         menu.show_all()
+        self._menu_hide_stuff(menu)
         return menu
+    def _menu_hide_stuff(self, menu):
+        """
+        Hide the menu if it has no menu items, or all menu items are hidden.
+        """
+        for sub in menu.get_children():
+            assert isinstance(sub, gtk.MenuItem)
+            if sub.get_submenu():
+                self._menu_hide_stuff(sub.get_submenu())
+                if not [c for c in sub.get_submenu().get_children() if c.props.visible]:
+                    sub.hide()
     def init_empty_file(self):
-        self.m_filedata = []
         self.m_changed = False
         self.m_filename = None
         self.m_savetime = time.time()
         self.set_title(self._get_a_filename())
+        self.g_ui_manager.get_widget("/ExportToolbar/SetRemove").set_sensitive(False)
     def _get_a_filename(self):
         """
         Return a file name. UntitledN (where N is an integer) if we
@@ -188,6 +258,7 @@ class TrainingSetDialog(gtk.Window):
          ('SetOpen', gtk.STOCK_OPEN, None, None, None, self.on_open),
          ('SetExport', gtk.STOCK_EXECUTE, _("Export"), None, None, self.on_export),
          ('SetAdd', gtk.STOCK_ADD, None, None, None, self.on_add_lesson_clicked),
+         ('SetRemove', gtk.STOCK_REMOVE, None, None, None, self.on_remove_lesson_clicked),
          ('SetHelp', gtk.STOCK_HELP, None, None, None, self.on_show_help),
         ])
         self.g_ui_manager.insert_action_group(actiongroup, 0)
@@ -195,6 +266,7 @@ class TrainingSetDialog(gtk.Window):
         <ui>
          <toolbar name='ExportToolbar'>
           <toolitem action='SetAdd'/>
+          <toolitem action='SetRemove'/>
           <toolitem action='SetNew'/>
           <toolitem action='SetOpen'/>
           <toolitem action='SetSave'/>
@@ -205,7 +277,7 @@ class TrainingSetDialog(gtk.Window):
          </toolbar>
         </ui>
         """
-        merge_id = self.g_ui_manager.add_ui_from_string(uixml)
+        self.g_ui_manager.add_ui_from_string(uixml)
         self.g_vbox.pack_start(self.g_ui_manager.get_widget("/ExportToolbar"), False)
         self.g_ui_manager.get_widget("/ExportToolbar").set_style(gtk.TOOLBAR_BOTH)
         hbox = gtk.HBox()
@@ -273,8 +345,7 @@ class TrainingSetDialog(gtk.Window):
     def load_file(self, filename):
         p = Dataparser({'yes': True, 'no': False}, {})
         p.parse_file(filename)
-        self.m_filedata = []#p.blocklists['lesson']
-        s = p.globals.get('output_format')
+        s = p.globals.setdefault('output_format', 'midi')
         s = s.lower()
         if s in self.g_output:
             self.g_output[s].set_active(True)
@@ -282,15 +353,12 @@ class TrainingSetDialog(gtk.Window):
             # MIDI is the default format
             self.g_output['midi'].set_active(True)
         self.m_filename = filename
-        for lesson in p.blocklists['lesson']:#self.m_filedata:
-            self.m_filedata.append({})
-            lesson_id = lesson['lesson_id']
-            self.append_lesson(self.get_lessonfile_title(lesson_id))
-            self.m_filedata[-1]['lesson_id'] = lesson['lesson_id']
-            self.m_filedata[-1]['count'].set_value(lesson['count'])
-            self.m_filedata[-1]['repeat'].set_value(lesson['repeat'])
-            self.m_filedata[-1]['delay'].set_value(lesson['delay'])
-        self.move_newbutton_last()
+        for lesson in p.blocklists.setdefault('lesson', []):
+            self.g_liststore.append((lesson['lesson_id'],
+                self.get_lessonfile_title(lesson['lesson_id']),
+                lesson['count'],
+                lesson['repeat'],
+                lesson['delay']))
         self.set_title(self.m_filename)
     def on_save_as(self, widget):
         """
@@ -343,22 +411,28 @@ class TrainingSetDialog(gtk.Window):
         Save the file to a file named by self.m_filename
         """
         assert self.m_filename
-        f = file(self.m_filename, 'w')
+        f = open(self.m_filename, 'w')
         print >> f, "# Training set definition file for GNU Solfege %s" % configureoutput.VERSION_STRING
         print >> f, "\nfileformat_version = %i" % self.fileformat_version
         print >> f, "output_format = \"%s\"" % [k for k in self.g_output if self.g_output[k].get_active()][0]
-        for x in self.m_filedata:
+        iter = self.g_liststore.get_iter_first()
+        while iter:
             print >> f, "lesson {"
-            if self.m_app.lessonfile_manager.get(x['lesson_id'], 'title'):
+            lesson_id = self.g_liststore.get_value(iter, self.STORE_LESSON_ID)
+            if self.m_app.lessonfile_manager.get(lesson_id, 'title'):
                 print >> f, "  # %s (%s)" % (
-                    self.m_app.lessonfile_manager.get(x['lesson_id'], 'title'),
-                    self.m_app.lessonfile_manager.get(x['lesson_id'], 'filename')
+                    self.m_app.lessonfile_manager.get(lesson_id, 'title'),
+                    self.m_app.lessonfile_manager.get(lesson_id, 'filename')
                     )
-            print >> f, '  lesson_id = "%s"' % x['lesson_id']
-            print >> f, '  count = %i' % x['count'].get_value_as_int()
-            print >> f, '  repeat = %i' % x['repeat'].get_value_as_int()
-            print >> f, '  delay = %i' % x['delay'].get_value_as_int()
+            print >> f, '  lesson_id = "%s"' % lesson_id
+            print >> f, '  count = %i' \
+                % self.g_liststore.get_value(iter, self.STORE_COUNT)
+            print >> f, '  repeat = %i' \
+                % self.g_liststore.get_value(iter, self.STORE_REPEAT)
+            print >> f, '  delay = %i' \
+                % self.g_liststore.get_value(iter, self.STORE_DELAY)
             print >> f, "}\n"
+            iter = self.g_liststore.iter_next(iter)
         f.close()
         self.m_changed = False
         self.m_savetime = time.time()
@@ -407,15 +481,23 @@ class TrainingSetDialog(gtk.Window):
         progress_dialog.vbox.pack_start(progress_bar)
         # We have to make a version of the data without gtk widgets
         v = []
-        for x in self.m_filedata:
-            v.append({})
-            for k in x.keys():
-                if isinstance(x[k], gtk.SpinButton):
-                    v[-1][k] = x[k].get_value_as_int()
-                else:
-                    v[-1][k] = x[k]
-
+        iter = self.g_liststore.get_iter_first()
+        while iter:
+            v.append({
+                'lesson_id': \
+                        self.g_liststore.get_value(iter, self.STORE_LESSON_ID),
+                'count': self.g_liststore.get_value(iter, self.STORE_COUNT),
+                'repeat': self.g_liststore.get_value(iter, self.STORE_REPEAT),
+                'delay': self.g_liststore.get_value(iter, self.STORE_DELAY),
+                        })
+            iter = self.g_liststore.iter_next(iter)
         output_format = [k for k in self.g_output if self.g_output[k].get_active()][0]
+        progress_dialog.queue_draw()
+        while gtk.events_pending():
+            gtk.main_iteration(0)
+        time.sleep(0.1)
+        while gtk.events_pending():
+            gtk.main_iteration(0)
         for prog in self.m_app.export_training_set(v, export_to, output_format):
             progress_bar.set_fraction(prog)
             while gtk.events_pending():
